<?php
/**
 * Yatego order transmission plugin
 * for osCommerce Online Merchant v2.2 RC 2a
 * (may also work with other versions)
 * 
 * Copy this file to the "admin" folder of your osCommerce installation.
 * Enter the URL of this file and a valid admin-user login into the
 * order-connection setup form within your Yatego Administration site.
 * 
 * Propagation of this file is forbidden without permission of Yatego GmbH.
 * 
 * Version: 1.0
 */

//Define payment methods
$aYategoPaymentMethods = Array(
	'Bankeinzug'					=> 'bank_collection',	//undefined; add as new payment method module to use
	'Vorauskasse / berweisung'		=> 'moneyorder',		//installed by default
	'Rechnung'						=> 'invoice',			//undefined; add as new payment method module to use
	'Nachnahme'						=> 'cod',				//installed by default
	'Barzahlung bei Selbstabholung' => 'cash',				//undefined; add as new payment method module to use
	'Kreditkarte'					=> 'cc',				//installed by default
	'iClear-Treuhandservice'		=> 'iclear',			//undefined; add as new payment method module to use
	'ELV'							=> 'bank_collection',	//undefined; add as new payment method module to use
	'Rechnung (Besichert)'			=> 'invoice'			//undefined; add as new payment method module to use
);

$sActualDateTime = date('Y-m-d H:i:s');

//Includes
include('includes/configure.php');
include(DIR_WS_INCLUDES.'database_tables.php');
require_once(DIR_WS_FUNCTIONS.'compatibility.php');
require_once(DIR_WS_FUNCTIONS.'general.php');
require_once(DIR_WS_FUNCTIONS.'database.php');
require_once(DIR_WS_FUNCTIONS.'password_funcs.php');

//DB-connect
tep_db_connect() or die('Unable to connect to database server!');

//Get default language
$pResultLanguage = tep_db_query('SELECT l.code, l.directory FROM '.TABLE_CONFIGURATION.' c LEFT JOIN '.TABLE_LANGUAGES.' l ON c.configuration_value = l.code WHERE configuration_key = \'DEFAULT_LANGUAGE\'');
$aLanguageInfo = tep_db_fetch_array($pResultLanguage);
define('DEFAULT_LANGUAGE', $aLanguageInfo['code']);
define('DEFAULT_LANGUAGE_DIRECTORY', $aLanguageInfo['directory']);

//Get serialized post-data
$aOrderRawData = unserialize(stripslashes($_POST[0]));

$sLoginUser		= tep_db_prepare_input($aOrderRawData['login']['username']);
$sLoginPassword	= tep_db_prepare_input($aOrderRawData['login']['password']);

if( $sLoginUser != '' && $sLoginPassword != '' )
{
	//Get user data
	$pResultAdminUser = tep_db_query('SELECT * FROM '.TABLE_ADMINISTRATORS.' WHERE user_name = \''.tep_db_input($sLoginUser).'\'');
	$aAdminUser = tep_db_fetch_array($pResultAdminUser);
	
	if( !tep_db_num_rows($pResultAdminUser) )
	{
		//User does not exist
		die( 'ERROR: Login Fehlgeschlagen! User existiert nicht.' );
	}
	else //User exists
	{
		//Validate user's password:
		if( !tep_validate_password($sLoginPassword, $aAdminUser['user_password']) )
			die('ERROR: Login Fehlgeschlagen! Falsches Passwort.');
		
		
		// Check if customer exists and add as new when not
		$pResultCustomer = tep_db_query('SELECT * FROM '.TABLE_CUSTOMERS.' WHERE customers_email_address = \''.tep_db_input($aOrderRawData['invoice_address']['email']).'\' AND customers_lastname = \''.tep_db_input($aOrderRawData['invoice_address']['last_name']).'\'');
		$aCustomer = tep_db_fetch_array($pResultCustomer);
		if( !$aCustomer['customers_id'] )
		{
			//Add new customer
			$cGender = ($aOrderRawData['invoice_address']['salutation'] == 'Frau') ? 'f' : 'm';
			$aCustomer = Array(
				'customers_gender'			=> $cGender,
				'customers_firstname'		=> $aOrderRawData['invoice_address']['first_name'],
				'customers_lastname'		=> $aOrderRawData['invoice_address']['last_name'],
				'customers_email_address'	=> $aOrderRawData['invoice_address']['email'],
				'customers_telephone'		=> $aOrderRawData['invoice_address']['phone'],
				'customers_fax'				=> $aOrderRawData['invoice_address']['fax'],
				'customers_dob'				=> $aOrderRawData['invoice_address']['birthday'] != '' ? $aOrderRawData['invoice_address']['birthday'].' 00:00:00' : 'null',
				'customers_newsletter'		=> 0,
				'customers_password'		=> tep_encrypt_password( uniqid('') )
			);
			
			tep_db_perform(TABLE_CUSTOMERS, $aCustomer);
			$aCustomer['customers_id'] = tep_db_insert_id();
			
			//Add customer info
			$aCustomerInfo = array(
				'customers_info_id'						=> $aCustomer['customers_id'],
				'customers_info_number_of_logons '		=> 0,
				'customers_info_date_account_created'	=> $sActualDateTime
			);
			
			tep_db_perform(TABLE_CUSTOMERS_INFO, $aCustomerInfo);
			
			//Add address book entry
			$pResultCountry = tep_db_query('SELECT countries_id FROM ' . TABLE_COUNTRIES . ' WHERE countries_iso_code_2 = \'' . $aOrderRawData['invoice_address']['country_code_iso2'] . '\'');
			$aCountry = tep_db_fetch_array($pResultCountry);
			
			$aCustomerAddressBook = array (
				'customers_id'			=> $aCustomerInfo['customers_info_id'],
				'entry_firstname'		=> $aOrderRawData['invoice_address']['first_name'],
				'entry_lastname'		=> $aOrderRawData['invoice_address']['last_name'],
				'entry_company'			=> $aOrderRawData['invoice_address']['company'],
				'entry_street_address'	=> $aOrderRawData['invoice_address']['street_address'],
				'entry_postcode'		=> $aOrderRawData['invoice_address']['post_code'],
				'entry_city'			=> $aOrderRawData['invoice_address']['city'],
				'entry_country_id'		=> $aCountry['countries_id'],
				'entry_gender'			=> $cGender
			);
			
			tep_db_perform(TABLE_ADDRESS_BOOK, $aCustomerAddressBook);
			$iAddressBookId = tep_db_insert_id();
			
			//Set default address
			tep_db_query("update ".TABLE_CUSTOMERS." set customers_default_address_id = '".$iAddressBookId."' where customers_id = '".$aCustomer['customers_id']."'");
			
			$bNewCustomerAdded = true;
		}//END create new customer
		
		if( $bNewCustomerAdded )
			echo 'NOTICE: Kunde neu angelegt.'."\r\n";
		else
			echo 'NOTICE: Kunde existiert bereits.'."\r\n";
		
		
		//Save order
		
		// TABLE_ORDERS:
		$aOrder['customers_id']					= $aCustomer['customers_id'];
		$aOrder['customers_name']				= $aOrderRawData['invoice_address']['first_name'].' '.$aOrderRawData['invoice_address']['last_name'];
		$aOrder['customers_company']			= $aOrderRawData['invoice_address']['company'];
		$aOrder['customers_street_address']		= $aOrderRawData['invoice_address']['street_address'];
		$aOrder['customers_city']				= $aOrderRawData['invoice_address']['city'];
		$aOrder['customers_postcode']			= $aOrderRawData['invoice_address']['post_code'];
		
		if ($aOrderRawData['invoice_address']['country_code_iso2'] != '')
		{
			$pResultCountry = tep_db_query('SELECT countries_name FROM '.TABLE_COUNTRIES.' WHERE countries_iso_code_2= \''.tep_db_input($aOrderRawData['invoice_address']['country_code_iso2']).'\'');
			$aCountryInfo = tep_db_fetch_array($pResultCountry);
			$aOrder['customers_country'] 		= $aCountryInfo['countries_name'];
		}
		
		$aOrder['customers_telephone']			= $aOrderRawData['invoice_address']['phone'];
		$aOrder['customers_email_address']		= $aOrderRawData['invoice_address']['email'];
		$aOrder['customers_address_format_id']	= 5;
		
		$aOrder['delivery_name']				= $aOrderRawData['delivery_address']['first_name'].' '.$aOrderRawData['delivery_address']['last_name'];
		$aOrder['delivery_company']				= $aOrderRawData['delivery_address']['company'];
		$aOrder['delivery_street_address']		= $aOrderRawData['delivery_address']['street_address'];
		$aOrder['delivery_city']				= $aOrderRawData['delivery_address']['city'];
		$aOrder['delivery_postcode']			= $aOrderRawData['delivery_address']['post_code'];
		$aOrder['delivery_address_format_id']	= 5;
		
		if ($aOrderRawData['delivery_address']['country_code_iso2'] != '')
		{
			$pResultCountry = tep_db_query('SELECT countries_name FROM '.TABLE_COUNTRIES.' WHERE countries_iso_code_2= \''.tep_db_input($aOrderRawData['delivery_address']['country_code_iso2']).'\'');
			$aCountryInfo = tep_db_fetch_array($pResultCountry);
			$aOrder['delivery_country']			= $aCountryInfo['countries_name'];
		}
		
		$aOrder['billing_name']					= $aOrderRawData['invoice_address']['first_name'].' '.$aOrderRawData['invoice_address']['last_name'];
		$aOrder['billing_company']				= $aOrderRawData['invoice_address']['company'];
		$aOrder['billing_street_address']		= $aOrderRawData['invoice_address']['street_address'];
		$aOrder['billing_city']					= $aOrderRawData['invoice_address']['city'];
		$aOrder['billing_postcode']				= $aOrderRawData['invoice_address']['post_code'];
		$aOrder['billing_country']				= $aOrder['customers_country'];
		$aOrder['billing_address_format_id']	= 5;
		
		@include(DIR_FS_CATALOG_LANGUAGES.DEFAULT_LANGUAGE_DIRECTORY.'/modules/payment/'.$aYategoPaymentMethods[ $aOrderRawData['order']['payment']['method'] ].'.php');
		if( @constant('MODULE_PAYMENT_'.strtoupper($aYategoPaymentMethods[ $aOrderRawData['order']['payment']['method'] ]).'_TEXT_TITLE') )
			$aOrder['payment_method'] = constant('MODULE_PAYMENT_'.strtoupper($aYategoPaymentMethods[ $aOrderRawData['order']['payment']['method'] ]).'_TEXT_TITLE');
		else
			$aOrder['payment_method'] = $aYategoPaymentMethods[ $aOrderRawData['order']['payment']['method'] ];
		
		$aOrder['date_purchased']				= $sActualDateTime;
		$aOrder['orders_status']				= 1;
		$aOrder['currency']						= 'EUR';
		$aOrder['currency_value']				= 1;
		
		tep_db_perform(TABLE_ORDERS, $aOrder);
		$iOrderId = tep_db_insert_id();
		
		
		//Add order items
		$aTaxesSums = array();
		$fSumTotalGross = 0;
		foreach( $aOrderRawData['items'] as $aItem )
		{
			//Get product id from model
			$pResultProduct = tep_db_query('SELECT products_id FROM '.TABLE_PRODUCTS.' WHERE products_model = \''.tep_db_input($aItem['id']).'\' LIMIT 1');
			$aProductInfo = tep_db_fetch_array($pResultProduct);
			
			//TABLE_ORDERS_PRODUCTS
			$aOrderProduct = array();
			$aOrderProduct['orders_id']				= $iOrderId;
			$aOrderProduct['products_id']			= $aProductInfo['products_id'];
			$aOrderProduct['products_model']		= $aItem['id'];
			$aOrderProduct['products_name']			= $aItem['title'];
			$aOrderProduct['products_price']		= $aItem['price_net'];
			$aOrderProduct['final_price']			= $aItem['price_net_total'];
			$aOrderProduct['products_tax']			= $aItem['tax'];
			$aOrderProduct['products_quantity']		= $aItem['quantity'];
			
			$aTaxesSums[(string)$aItem['tax']] += $aItem['price_net_total'] * $aItem['quantity'];
			$fSumTotalGross += round( ($aItem['price_net_total'] * $aItem['quantity']) + ( (($aItem['price_net_total'] * $aItem['quantity']) / 100) * $aItem['tax'] ), 2 );
			
			tep_db_perform(TABLE_ORDERS_PRODUCTS, $aOrderProduct);
			$iOrderProductId = tep_db_insert_id();
			
			
			//TABLE_ORDERS_PRODUCTS_ATTRIBUTES (variants)
			if( is_array($aItem['variants']) )
			{
				foreach( $aItem['variants'] as $aItemVariant )
				{
					$aOrderProductAttributes = array();
					$aOrderProductAttributes['orders_id']				= $iOrderId;
					$aOrderProductAttributes['orders_products_id']		= $iOrderProductId;
					$aOrderProductAttributes['products_options']		= $aItemVariant['variantsetname'];
					$aOrderProductAttributes['products_options_values']	= $aItemVariant['variantname'];
					$aOrderProductAttributes['options_values_price']	= abs($aItemVariant['additional_price_net']);
					$aOrderProductAttributes['price_prefix']			= $aItemVariant['additional_price_net'] < 0 ? '-' : '+';
					
					tep_db_perform(TABLE_ORDERS_PRODUCTS_ATTRIBUTES, $aOrderProductAttributes);
				}
			}
		}//END foreach items
		
		//TABLE_ORDERS_STATUS_HISTORY
		$aOrderStatusHistory = array();
		$aOrderStatusHistory['orders_id']			= $iOrderId;
		$aOrderStatusHistory['orders_status_id']	= 1;
		$aOrderStatusHistory['date_added']			= $sActualDateTime;
		$aOrderStatusHistory['customer_notified']	= 1;
		$aOrderStatusHistory['comments ']			= 'Bestellung wurde ber Yatego gettigt. Yatego Bestellnummer: '.$aOrderRawData['order']['order_nr']."\n\n".$aOrderRawData['order']['customer_remark'];
		
		tep_db_perform(TABLE_ORDERS_STATUS_HISTORY, $aOrderStatusHistory);
		
		
		
		
		//TABLE_ORDERS_TOTAL //Anzeige der Bestellungen im Admin
		
		$aOrdersTotal = array(
			'orders_id' 	=> $iOrderId, 
			'title' 		=> 'Zwischensumme:', 
			'text'			=> number_format( round($fSumTotalGross, 2), 2, ',', '.').'',
			'value'			=> round($fSumTotalGross, 4), 
			'class' 		=> 'ot_subtotal',
			'sort_order'	=> 1
		);
		tep_db_perform(TABLE_ORDERS_TOTAL, $aOrdersTotal);
		
		$i = 0;
		foreach( $aTaxesSums as $iTaxrate => $fTaxRateSum )
		{
			$fTaxSum = ($fTaxRateSum / 100) * $iTaxrate;
			$aOrdersTotal = array(
				'orders_id' 	=> $iOrderId, 
				'title' 		=> 'enthaltene MwSt. ('.$iTaxrate.'%):', 
				'text'			=> number_format($fTaxSum, 2, ',', '.').'',
				'value'			=> round($fTaxSum, 4), 
				'class' 		=> 'ot_tax',
				'sort_order'	=> 2 + $i
			);
			tep_db_perform(TABLE_ORDERS_TOTAL, $aOrdersTotal);
			$i++;
		}
		
		
		$aOrdersTotal = array(
			'orders_id' 	=> $iOrderId, 
			'title' 		=> 'Versandkosten (inkl. MwSt. '.$aOrderRawData['order']['shipping']['cost_gross'].'%): ', 
			'text'			=> number_format($aOrderRawData['order']['shipping']['cost_gross'], 2, ',', '.').'',
			'value'			=> round($aOrderRawData['order']['shipping']['cost_gross'], 4), 
			'class' 		=> 'ot_shiping',
			'sort_order'	=> 10
		);
		tep_db_perform(TABLE_ORDERS_TOTAL, $aOrdersTotal);
		
		
		$fSum = round( round($fSumTotalGross, 2) + round($aOrderRawData['order']['shipping']['cost_gross'], 2), 2 );
		$aOrdersTotal = array(
			'orders_id' 	=> $iOrderId, 
			'title' 		=> '<b>Summe</b>: ', 
			'text'			=> '<b> '.number_format(round($fSum, 2), 2, ",", ".").'</b>',
			'value'			=> $fSum, 
			'class' 		=> 'ot_total',
			'sort_order'	=> 11
		);
		tep_db_perform(TABLE_ORDERS_TOTAL, $aOrdersTotal);
		
		echo 'SUCCESS: Bestellbertragung erfolgreich!';
	}
}
else
{
	print 'ERROR: Diese Seite bentigt Login-Daten!';
}
?>